#
# spec file for package noise-suppression-for-voice
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           noise-suppression-for-voice
Version:        1.10+git0.9c4e5c2
Release:        1.4
Summary:        Noise suppression plugin based on Xiph's RNNoise
License:        GPL-3.0-only
URL:            https://github.com/werman/noise-suppression-for-voice
Source:         %{name}-%{version}.tar.xz
BuildRequires:  Mesa-libGL-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ladspa
BuildRequires:  ladspa-devel
BuildRequires:  libXcursor-devel
BuildRequires:  libXrandr-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)

%description
The plugin is meant to suppress a wide range of noise origins
(from original paper): computer fans, office, crowd, airplane,
car, train, construction.

From my tests mild background noise is always suppressed,
loud sounds, like clicking of mechanical keyboard, are
suppressed while there is no voice however they are only
reduced in volume when voice is present.

The plugin is made to work with 1 channel and/or 2 channels
(ladspa plugin), 16 bit, 48000 Hz audio input.
Other sample rates may work, or not...

%package     -n lv2-rnnoise
Summary:        Noise suppression plugin based on Xiph's RNNoise - lv2 plugin

%description -n lv2-rnnoise
The plugin is meant to suppress a wide range of noise origins
(from original paper): computer fans, office, crowd, airplane,
car, train, construction.

From my tests mild background noise is always suppressed,
loud sounds, like clicking of mechanical keyboard, are
suppressed while there is no voice however they are only
reduced in volume when voice is present.

The plugin is made to work with 1 channel and/or 2 channels
(ladspa plugin), 16 bit, 48000 Hz audio input.
Other sample rates may work, or not...

This package holds the lv2 plugin.

%package     -n vst3-rnnoise
Summary:        Noise suppression plugin based on Xiph's RNNoise - vst3 plugin

%description -n vst3-rnnoise
The plugin is meant to suppress a wide range of noise origins
(from original paper): computer fans, office, crowd, airplane,
car, train, construction.

From my tests mild background noise is always suppressed,
loud sounds, like clicking of mechanical keyboard, are
suppressed while there is no voice however they are only
reduced in volume when voice is present.

The plugin is made to work with 1 channel and/or 2 channels
(ladspa plugin), 16 bit, 48000 Hz audio input.
Other sample rates may work, or not...

This package holds the vst3 plugin.

%package     -n vst-rnnoise
Summary:        Noise suppression plugin based on Xiph's RNNoise - vst plugin

%description -n vst-rnnoise
The plugin is meant to suppress a wide range of noise origins
(from original paper): computer fans, office, crowd, airplane,
car, train, construction.

From my tests mild background noise is always suppressed,
loud sounds, like clicking of mechanical keyboard, are
suppressed while there is no voice however they are only
reduced in volume when voice is present.

The plugin is made to work with 1 channel and/or 2 channels
(ladspa plugin), 16 bit, 48000 Hz audio input.
Other sample rates may work, or not...

This package holds the vst plugin.

%package     -n ladspa-rnnoise
Summary:        Noise suppression plugin based on Xiph's RNNoise - ladspa plugin

%description -n ladspa-rnnoise
The plugin is meant to suppress a wide range of noise origins
(from original paper): computer fans, office, crowd, airplane,
car, train, construction.

From my tests mild background noise is always suppressed,
loud sounds, like clicking of mechanical keyboard, are
suppressed while there is no voice however they are only
reduced in volume when voice is present.

The plugin is made to work with 1 channel and/or 2 channels
(ladspa plugin), 16 bit, 48000 Hz audio input.
Other sample rates may work, or not...

This package holds the ladspa plugin.

%prep
%autosetup -p1

sed -i -e 's/lxvst/vst/' src/juce_plugin/CMakeLists.txt

%build
%ifarch x86_64
# Build with SIMD extension
%cmake -DBUILD_RTCD:BOOL=ON
%else
%cmake
%endif
%cmake_build

%install
%cmake_install

%files -n ladspa-rnnoise
%license LICENSE
%doc README.md
%{_libdir}/ladspa/librnnoise_ladspa.so

%files -n lv2-rnnoise
%license LICENSE
%doc README.md
%{_libdir}/lv2/

%files -n vst3-rnnoise
%license LICENSE
%doc README.md
%{_libdir}/vst3/

%files -n vst-rnnoise
%license LICENSE
%doc README.md
%dir %{_libdir}/vst
%{_libdir}/vst/

%changelog
* Mon May 20 2024 pallaswept@proton.me
- Update to version 1.10+git0.9c4e5c2:
  * ci: Change windows-latest to windows-2019 due to internal compiler error
  * rnnoise: Remove previous rnnoise version
  * common: Switch to updated rnnoise v0.2
  * external/rnnoise: Add CMakeLists.txt to build as a static lib
  * external/rnnoise: Add generated weights
  * git subrepo clone https://github.com/xiph/rnnoise external/rnnoise
  * build: Unique LV2URI
  * JUCE/VST2: Prevent crash of effGetSpeakerArrangement with null in/out
  * cmake: Add option to use external JUCE installation
  * Add some `=` signs to the PipeWire config snippet
* Wed Aug  3 2022 kv@kott.no-ip.biz
- Update to version 1.03+git1.226f03b:
  * readme: Rename pulseeffects to easyeffects, add a small detail
  * common: Fix VAD calculations
  * readme: Add note about MinGW build failure
  * fst: Use fixed size types to for fst typedefs
  * fst: Handle EditIdle
  * gui: Fix window having leftovers from past updates
  * ci: Fix wrong name for macos archive
  * ci: Disable parallel build on Ubuntu to prevent oom
  * tests: Fix wrong comparison left after local tests
  * readme: Small update for PulseAudio
  * tests: Reduce time of "All options" test
  * readme: Small update
  * common: Do not wait for frames when receiving large input
  * cmake: Enable lto for releases
  * cmake: Support install target for Unix systems
  * cmake: Add BUILD_VERSION as cmake parameter
  * ci: Add workflow for releases
  * git subrepo pull (merge) --branch=master --update external/JUCE
  * subrepo/juce: Fixup parent commit for subrepo
  * juce_plugin: Fix state restoring
  * ci: Build "Release" build for Windows
  * ci: Trigger full build on tag push
  * readme: Update readme for new version
  * ladspa: Change units from "blocks" to "ms" for parameters
  * juce_plugin/gui: Improved paramemters naming and added headers
  * common: Do not create excessive latency when changing retroactive VAD
  * CI: Exclude .pdb from artifacts
  * JUCE: Disable LTO for juceaide to save build time
  * Use JUCE, new parameters, stereo, tests
  * external: Add header-only catch2
  * JUCE: Add LV2_COPY_DIR property
  * JUCE: Remove splash screen
  * JUCE: Use FST headers instead of VST2
  * git subrepo clone --branch=juce7 https://github.com/juce-framework/JUCE.git external/JUCE
  * git subrepo clone https://git.iem.at/zmoelnig/FST.git external/FST/
  * Pipewire persistency
  * URL fix
* Fri Jan 28 2022 dmueller@suse.com
- Update to version 0.91+git8.6922453:
  * Added hint for latency or crackling problems.
  * Make instruction to copy VST sdk files more explicit
  * Add link to archive.org for VST2 sdk
  * Add a how-to for PipeWire
  * common: do not dereference first element of zero-sized output buffer
  * typo in readme
  * Remove lib prefix from lv2 plugin binary.
  * Also copy .ttl files for lv2 plugin and fix path
  * Update documentation with adjustment to prevent loopback switching source/sink
  * Add a link to the guide for EqualizerAPO
* Mon Jun 29 2020 Marcus Rueckert <mrueckert@suse.de>
- initial package
